@@ -166,6 +166,16 @@ const bool ConfigItems::load( const bool restore )
     // ipv6使用
     use_ipv6 = cf.get_option_bool( "use_ipv6", CONF_USE_IPV6 );
 
+    // 同一ホストに対する最大コネクション数( 1 または 2 )
+    connection_num = cf.get_option_int( "connection_num", CONF_CONNECTION_NUM, 1, 2 );
+
+    // 2chのクッキー:HAPを保存する
+    use_cookie_hap = cf.get_option_bool( "use_cookie_hap", CONF_USE_COOKIE_HAP );
+
+    // 2chのクッキー:HAP
+    cookie_hap = cf.get_option_str( "cookie_hap", CONF_COOKIE_HAP );
+    cookie_hap_bbspink = cf.get_option_str( "cookie_hap_bbspink", CONF_COOKIE_HAP_BBSPINK );
+
     // ブラウザ設定ダイアログのコンボボックスの番号
     browsercombo_id = cf.get_option_int( "browsercombo_id", CONF_BROWSER_NO, 0, CORE::get_browser_number() -1 );
 
@@ -202,6 +212,13 @@ const bool ConfigItems::load( const bool restore )
     // ssspアイコン表示
     show_ssspicon = cf.get_option_bool( "show_ssspicon", CONF_SHOW_SSSPICON );
 
+    // インライン画像の最大幅と高さ
+    embimg_width = cf.get_option_int( "embimg_width", CONF_EMBIMG_WIDTH, 16, 8192 );
+    embimg_height = cf.get_option_int( "embimg_height", CONF_EMBIMG_HEIGHT, 16, 8192 );
+
+    // 画像ビューでdeleteを押したときに確認ダイアログを表示する
+    show_delimgdiag = cf.get_option_bool( "show_delimgdiag", CONF_SHOW_DELIMGDIAG );
+
     // 画像にモザイクをかける
     use_mosaic = cf.get_option_bool( "use_mosaic", CONF_USE_MOSAIC );
 
@@ -235,6 +252,9 @@ const bool ConfigItems::load( const bool restore )
     // p2の認証サーバのアドレス
     url_loginp2 = cf.get_option_str( "url_loginp2", CONF_LOGINP2 );
 
+    // BEの認証サーバのアドレス
+    url_loginbe = cf.get_option_str( "url_loginbe", CONF_LOGINBE );
+
     // bbsmenu.htmlのURL
     url_bbsmenu = cf.get_option_str( "url_bbsmenu", CONF_URL_BBSMENU );
 
@@ -268,9 +288,21 @@ const bool ConfigItems::load( const bool restore )
     // ツリービューの行間スペース
     tree_ypad = cf.get_option_int( "tree_ypad", CONF_TREE_YPAD, 0, 64 );
 
+    // ツリービューにエクスパンダを表示
+    tree_show_expanders = cf.get_option_bool( "tree_show_expanders", CONF_TREE_SHOW_EXPANDERS );
+
+    // ツリービューのレベルインデント調整量(ピクセル)
+    tree_level_indent = cf.get_option_int( "tree_level_indent", CONF_TREE_LEVEL_INDENT, -256, 256 );
+
+    // カテゴリを開いたときにツリービューをスクロールする
+    scroll_tree = cf.get_option_bool( "scroll_tree", CONF_SCROLL_TREE );
+
     // 各ビューと枠との間の余白
     view_margin = cf.get_option_int( "view_margin", CONF_VIEW_MARGIN, 0, 64 );
 
+    // スクロールバーを左に配置
+    left_scrbar = cf.get_option_bool( "left_scrbar", CONF_LEFT_SCRBAR );
+
     // スレ一覧で古いスレも表示
     show_oldarticle = cf.get_option_bool( "show_oldarticle", CONF_SHOW_OLDARTICLE );
 
@@ -311,7 +343,7 @@ const bool ConfigItems::load( const bool restore )
     live_mode = cf.get_option_int( "live_mode", LIVE_SCRMODE_VARIABLE, 0, LIVE_SCRMODE_NUM -1 );
 
     // 実況速度
-    live_speed = cf.get_option_int( "live_speed", CONF_LIVE_SPEED, 1, 1024 );
+    live_speed = cf.get_option_int( "live_speed", CONF_LIVE_SPEED, 0, 50 );
 
     // 実況のスクロールモードを切り替えるしきい値
     live_threshold = cf.get_option_int( "live_threshold", CONF_LIVE_THRESHOLD, 1, 1024 );
@@ -322,6 +354,12 @@ const bool ConfigItems::load( const bool restore )
     // お気に入りでカテゴリを常にひとつだけ開く
     open_one_favorite = cf.get_option_bool( "open_one_favorite", CONF_OPEN_ONE_FAVORITE );
 
+    // デフォルトの書き込み名
+    write_name = cf.get_option_str( "write_name", CONF_WRITE_NAME );
+
+    // デフォルトのメールアドレス
+    write_mail = cf.get_option_str( "write_mail", CONF_WRITE_MAIL );
+
     // 書き込み時に書き込み確認ダイアログを出さない
     always_write_ok = cf.get_option_bool( "always_write_ok", CONF_ALWAYS_WRITE_OK );
 
@@ -337,21 +375,40 @@ const bool ConfigItems::load( const bool restore )
     // 「書き込み中」のダイアログを表示しない
     hide_writing_dialog = cf.get_option_bool( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
 
+    // 編集中のメッセージの保存確認ダイアログを表示する
+    show_savemsgdiag = cf.get_option_bool( "show_savemsgdiag", CONF_SHOW_SAVEMSGDIAG );
+
+    // 書き込みビューでテキストを折り返す
+    message_wrap = cf.get_option_bool( "message_wrap", CONF_MESSAGE_WRAP );
+
     // 非アクティブ時に書き込みビューを折りたたむ
     fold_message = cf.get_option_bool( "fold_message", CONF_FOLD_MESSAGE );
 
+    // 非アクティブ時に画像ビューを折りたたむ
+    fold_image = cf.get_option_bool( "fold_image", CONF_FOLD_IMAGE );
+
     // 書き込み欄の日本語のON/OFF状態を保存
     keep_im_status = cf.get_option_bool( "keep_im_status", CONF_KEEP_IM_STATUS );
 
     // ポップアップとカーソルの間のマージン
-    margin_popup = cf.get_option_int( "margin_popup", CONF_MARGIN_POPUP, 1, 1024 );
+    margin_popup = cf.get_option_int( "margin_popup", CONF_MARGIN_POPUP, 0, 1024 );
 
     // 画像ポップアップとカーソルの間のマージン
-    margin_imgpopup = cf.get_option_int( "margin_imgpopup", CONF_MARGIN_IMGPOPUP, 1, 1024 );
+    margin_imgpopup_x = cf.get_option_int( "margin_imgpopup_x", CONF_MARGIN_IMGPOPUP_X, 0, 1024 );
+    margin_imgpopup = cf.get_option_int( "margin_imgpopup", CONF_MARGIN_IMGPOPUP, 0, 1024 );
+
+    // ポップアップが消えるまでの時間(ミリ秒)
+    hide_popup_msec = cf.get_option_int( "hide_popup_msec", CONF_HIDE_POPUP_MSEC, 0, 2000 );
+
+    // マウスジェスチャを有効
+    enable_mg = cf.get_option_bool( "enable_mg", CONF_ENABLE_MG );
 
     // マウスジェスチャの判定開始半径
     mouse_radius = cf.get_option_int( "mouse_radius", CONF_MOUSE_RADIUS, 4, 1024 );
 
+    // 数字入力ジャンプの待ち時間(ミリ秒)
+    numberjmp_msec = cf.get_option_int( "numberjmp_msec", CONF_NUMBERJMP_MSEC, 1, 5000 );
+
     // 履歴メニューの表示数
     history_size = cf.get_option_int( "history_size", CONF_HISTORY_SIZE, 0, 256 );
 
@@ -430,6 +487,9 @@ const bool ConfigItems::load( const bool restore )
     str_tmp = cf.get_option_str( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) list_abone_regex_thread = MISC::strtolist( str_tmp );
 
+    // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
+    remove_old_abone_thread = cf.get_option_int( "remove_old_abone_thread", CONF_REMOVE_OLD_ABONE_THREAD, 0, 2 );
+
     // スレ あぼーん( レス数 )
     abone_number_thread = cf.get_option_int( "abone_number_thread", CONF_ABONE_NUMBER_THREAD, 0, 9999 );
 
@@ -452,17 +512,24 @@ const bool ConfigItems::load( const bool restore )
     abone_transparent = cf.get_option_bool( "abone_transparent", CONF_ABONE_TRANSPARENT );
     abone_chain = cf.get_option_bool( "abone_chain", CONF_ABONE_CHAIN );
 
+    // NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+    abone_icase = cf.get_option_bool( "abone_icase", CONF_ABONE_ICASE );
+    abone_wchar = cf.get_option_bool( "abone_wchar", CONF_ABONE_WCHAR );
+
     // 右ペーンが空の時にサイドバーを閉じるか
     expand_sidebar = cf.get_option_bool( "expand_sidebar", CONF_EXPAND_SIDEBAR );
 
     // 3ペーン時にスレ一覧やスレビューを最大化する
     expand_rpane = cf.get_option_bool( "expand_rpane", CONF_EXPAND_RPANE );
 
+    // ペーンの境界をクリックしてサイドバーを開け閉めする
+    open_sidebar_by_click = cf.get_option_bool( "open_sidebar_by_click", CONF_OPEN_SIDEBAR_BY_CLICK );
+
     // 次スレ検索の類似度のしきい値
     threshold_next = cf.get_option_int( "threshold_next", CONF_THRESHOLD_NEXT, 1, 10 );
 
     // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-    replace_favorite_next = cf.get_option_bool( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT );
+    replace_favorite_next = cf.get_option_int( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT, 0, 2 );
 
     // お気に入りの自動更新をするかダイアログを出す
     show_diag_replace_favorite = cf.get_option_bool( "show_diag_replace_favorite", CONF_SHOW_DIAG_REPLACE_FAVORITE );
@@ -476,15 +543,36 @@ const bool ConfigItems::load( const bool restore )
     // 起動時にお気に入りを自動でチェックする
     check_update_boot = cf.get_option_bool( "check_update_boot", CONF_CHECK_UPDATE_BOOT );
 
+    // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示  2: 登録しない )
+    check_favorite_dup = cf.get_option_int( "check_favorite_dup", CONF_CHECK_FAVORITE_DUP, 0, 2 );
+
+    // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+    show_favorite_select_diag = cf.get_option_int( "show_favorite_select_diag", CONF_SHOW_FAVORITE_SELECT_DIAG, 0, 2 );
+
     // Ctrl+qでウィンドウを閉じない
     disable_close = cf.get_option_bool( "disable_close", CONF_DISABLE_CLOSE );
 
+    // メニューバーを非表示にした時にダイアログを表示
+    show_hide_menubar_diag = cf.get_option_bool( "show_hide_menubar_diag", CONF_SHOW_HIDE_MENUBAR_DIAG );
+
+    // 状態変更時にメインステータスバーの色を変える
+    change_stastatus_color = cf.get_option_bool( "change_stastatus_color", CONF_CHANGE_STASTATUS_COLOR );
+
     // まちBBSの取得に offlaw.cgi を使用する
     use_machi_offlaw = cf.get_option_bool( "use_machi_offlaw", CONF_USE_MACHI_OFFLAW );
 
     // 書き込み履歴のあるスレを削除する時にダイアログを表示
     show_del_written_thread_diag = cf.get_option_bool( "show_del_written_thread_diag", CONF_SHOW_DEL_WRITTEN_THREAD_DIAG );
 
+    // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+    delete_img_in_thread = cf.get_option_int( "delete_img_in_thread", CONF_DELETE_IMG_IN_THREAD, 0, 2 );
+
+    // FIFOの作成などにエラーがあったらダイアログを表示する
+    show_diag_fifo_error = cf.get_option_bool( "show_diag_fifo_error", CONF_SHOW_DIAG_FIFO_ERROR );
+
+    // 指定した分ごとにセッションを自動保存 (0: 保存しない)
+    save_session = cf.get_option_int( "save_session", CONF_SAVE_SESSION, 0, (24*60) );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     migemodict_path = cf.get_option_str( "migemodict_path", CONF_MIGEMO_PATH );
@@ -501,7 +589,7 @@ const bool ConfigItems::load( const bool restore )
         // 非resotreモードでバックアップが存在する
         if( ! restore && CACHE::file_exists( CACHE::path_conf_bkup() ) == CACHE::EXIST_FILE )
         {
-            msg = path_conf + "に異常な値があります。全設定をバックアップから復元しますか？";
+            msg = "設定ファイル (" + path_conf + ")に異常な値があります。全設定をバックアップから復元しますか？";
             mdiag = new Gtk::MessageDialog( msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
             int ret = mdiag->run();
             delete mdiag;
@@ -509,7 +597,7 @@ const bool ConfigItems::load( const bool restore )
         }
         else
         {
-            msg = path_conf + "に異常な値があるため、一部をデフォルトに設定しました。";
+            msg = "設定ファイル (" + path_conf + ")に異常な値があるため、一部をデフォルトに設定しました。";
             mdiag = new Gtk::MessageDialog( msg );
             mdiag->run();
             delete mdiag;
@@ -550,6 +638,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "url_jdhp", url_jdhp );
     cf.update( "url_login2ch", url_login2ch );
     cf.update( "url_loginp2", url_loginp2 );
+    cf.update( "url_loginbe", url_loginbe );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
     cf.update( "show_movediag", show_movediag );
@@ -606,6 +695,11 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "loader_timeout_checkupdate", loader_timeout_checkupdate );
 
     cf.update( "use_ipv6", use_ipv6 );
+    cf.update( "connection_num", connection_num );
+
+    cf.update( "use_cookie_hap", use_cookie_hap );
+    cf.update( "cookie_hap", cookie_hap );
+    cf.update( "cookie_hap_bbspink", cookie_hap_bbspink );
 
     cf.update( "command_openurl", command_openurl );
     cf.update( "browsercombo_id", browsercombo_id );
@@ -623,6 +717,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_image_view", use_image_view );
     cf.update( "use_inline_image", use_inline_image );
     cf.update( "show_ssspicon", show_ssspicon );
+    cf.update( "embimg_width", embimg_width );
+    cf.update( "embimg_height", embimg_height );
+    cf.update( "show_delimgdiag", show_delimgdiag );
     cf.update( "use_mosaic", use_mosaic );
     cf.update( "mosaic_size", mosaic_size );
     cf.update( "zoom_to_fit", zoom_to_fit );
@@ -670,9 +767,15 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_select_gtkrc", use_select_gtkrc );
 
     cf.update( "tree_ypad", tree_ypad );
+    cf.update( "tree_show_expanders", tree_show_expanders );
+    cf.update( "tree_level_indent", tree_level_indent );
+
+    cf.update( "scroll_tree", scroll_tree );
 
     cf.update( "view_margin", view_margin );
 
+    cf.update( "left_scrbar", left_scrbar );
+
     cf.update( "show_oldarticle", show_oldarticle );
     cf.update( "newthread_hour", newthread_hour );
     cf.update( "inc_search_board", inc_search_board );
@@ -693,16 +796,26 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "open_one_category", open_one_category );
     cf.update( "open_one_favorite", open_one_favorite );
+
+    cf.update( "write_mail", write_mail );
+    cf.update( "write_name", write_name );
     cf.update( "always_write_ok", always_write_ok );
     cf.update( "save_postlog", save_postlog );
     cf.update( "maxsize_postlog", maxsize_postlog );
     cf.update( "save_posthist", save_posthist );
     cf.update( "hide_writing_dialog", hide_writing_dialog );
+    cf.update( "show_savemsgdiag", show_savemsgdiag );
+    cf.update( "message_wrap", message_wrap );
     cf.update( "fold_message", fold_message );
+    cf.update( "fold_image", fold_image );
     cf.update( "keep_im_status", keep_im_status );
     cf.update( "margin_popup", margin_popup );
+    cf.update( "margin_imgpopup_x", margin_imgpopup_x );
     cf.update( "margin_imgpopup", margin_imgpopup );
+    cf.update( "hide_popup_msec", hide_popup_msec );
+    cf.update( "enable_mg", enable_mg );
     cf.update( "mouse_radius", mouse_radius );
+    cf.update( "numberjmp_msec", numberjmp_msec );
     cf.update( "history_size", history_size );
     cf.update( "historyview_size", historyview_size );
     cf.update( "aahistory_size", aahistory_size );
@@ -743,6 +856,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "abonewordthread", str_abone_word_thread );
     cf.update( "aboneregexthread", str_abone_regex_thread );
 
+    cf.update( "remove_old_abone_thread", remove_old_abone_thread );
+
     cf.update( "abone_number_thread", abone_number_thread );
     cf.update( "abone_hour_thread", abone_hour_thread );
 
@@ -758,18 +873,30 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "abone_transparent", abone_transparent );
     cf.update( "abone_chain", abone_chain );
 
+    cf.update( "abone_icase", abone_icase );
+    cf.update( "abone_wchar", abone_wchar );
+
     cf.update( "expand_sidebar", expand_sidebar );
     cf.update( "expand_rpane", expand_rpane );
 
+    cf.update( "open_sidebar_by_click", open_sidebar_by_click );
+
     cf.update( "threshold_next", threshold_next );
     cf.update( "replace_favorite_next", replace_favorite_next );
     cf.update( "show_diag_replace_favorite", show_diag_replace_favorite );
     cf.update( "bookmark_drop", bookmark_drop );
     cf.update( "check_update_board", check_update_board );
     cf.update( "check_update_boot", check_update_boot );
+    cf.update( "check_favorite_dup", check_favorite_dup );
+    cf.update( "show_favorite_select_diag", show_favorite_select_diag );
     cf.update( "disable_close", disable_close );
+    cf.update( "show_hide_menubar_diag", show_hide_menubar_diag );
+    cf.update( "change_stastatus_color", change_stastatus_color );
     cf.update( "use_machi_offlaw", use_machi_offlaw );
     cf.update( "show_del_written_thread_diag", show_del_written_thread_diag );
+    cf.update( "delete_img_in_thread", delete_img_in_thread );
+    cf.update( "show_diag_fifo_error", show_diag_fifo_error );
+    cf.update( "save_session", save_session );
 
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
@@ -951,7 +1078,13 @@ void ConfigItems::set_proxy_for2ch( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         proxy_basicauth_for2ch = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         proxy_for2ch = regex.str( 2 );
@@ -966,7 +1099,13 @@ void ConfigItems::set_proxy_for2ch_w( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         proxy_basicauth_for2ch_w = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         proxy_for2ch_w = regex.str( 2 );
@@ -981,7 +1120,13 @@ void ConfigItems::set_proxy_for_data( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         proxy_basicauth_for_data = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         proxy_for_data = regex.str( 2 );
