@@ -87,6 +87,16 @@ namespace CONFIG
         // ipv6使用
         bool use_ipv6;
 
+        // 同一ホストに対する最大コネクション数( 1 または 2 )
+        int connection_num;
+
+        // 2chのクッキー:HAPを保存する
+        bool use_cookie_hap;
+
+        // 2chのクッキー:HAP
+        std::string cookie_hap;
+        std::string cookie_hap_bbspink;
+
         // リンクをクリックしたときに実行するコマンド
         std::string command_openurl;
 
@@ -123,6 +133,13 @@ namespace CONFIG
         // ssspアイコン表示
         bool show_ssspicon;
 
+        // インライン画像の最大幅と高さ
+        int embimg_width;
+        int embimg_height;
+
+        // 画像ビューでdeleteを押したときに確認ダイアログを表示する
+        bool show_delimgdiag;
+
         // 画像にモザイクかける
         bool use_mosaic;
 
@@ -158,6 +175,9 @@ namespace CONFIG
         // p2の認証サーバのアドレス
         std::string url_loginp2;
 
+        // BEの認証サーバのアドレス
+        std::string url_loginbe;
+
         // bbsmenu.htmlのURL
         std::string url_bbsmenu;
 
@@ -194,13 +214,22 @@ namespace CONFIG
         // ツリービューの行間スペース
         int tree_ypad;
 
+        // ツリービューにエクスパンダを表示
+        bool tree_show_expanders;
+
+        // ツリービューのレベルインデント調整量(ピクセル)
+        int tree_level_indent;
+
         // カテゴリを開いたときにツリービューをスクロールする
         bool scroll_tree;
 
         // 各ビューと枠との間の余白
         int view_margin;
 
-        // スレ一覧で古いスレも表示
+        // スクロールバーを左に配置
+        bool left_scrbar;
+
+        // スレ一覧で古いスレも表示 	 
         bool show_oldarticle;
 
         // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
@@ -251,6 +280,12 @@ namespace CONFIG
         // お気に入りでカテゴリを常にひとつだけ開く
         bool open_one_favorite;
 
+        // デフォルトの書き込み名
+        std::string write_name;
+
+        // デフォルトのメールアドレス
+        std::string write_mail;
+
         // 書き込み時に書き込み確認ダイアログを出さない
         bool always_write_ok;
 
@@ -266,9 +301,18 @@ namespace CONFIG
         // 「書き込み中」のダイアログを表示しない
         bool hide_writing_dialog;
 
+        // 編集中のメッセージの保存確認ダイアログを表示する
+        bool show_savemsgdiag;
+
+        // 書き込みビューでテキストを折り返す
+        bool message_wrap;
+
         // 非アクティブ時に書き込みビューを折りたたむ
         bool fold_message;
 
+        // 非アクティブ時に画像ビューを折りたたむ
+        bool fold_image;
+
         // 書き込み欄の日本語のON/OFF状態を保存
         bool keep_im_status;
 
@@ -276,11 +320,21 @@ namespace CONFIG
         int margin_popup;
 
         // 画像ポップアップとカーソルの間のマージン
-        int margin_imgpopup;
+        int margin_imgpopup_x;  // 水平方向
+        int margin_imgpopup; // 垂直方向
+
+        // ポップアップが消えるまでの時間(ミリ秒)
+        int hide_popup_msec;
+
+        // マウスジェスチャを有効
+        bool enable_mg;
 
         // マウスジェスチャの判定開始半径
         int mouse_radius;
 
+        // 数字入力ジャンプの待ち時間(ミリ秒)
+        int numberjmp_msec;
+
         // 履歴メニューの表示数
         int history_size;
 
@@ -354,6 +408,9 @@ namespace CONFIG
         // スレ あぼーん regex
         std::list< std::string > list_abone_regex_thread;
 
+        // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
+        int remove_old_abone_thread;
+
         // スレ あぼーん レス数
         int abone_number_thread;
 
@@ -373,17 +430,24 @@ namespace CONFIG
         bool abone_transparent;
         bool abone_chain;
 
+        // NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+        bool abone_icase;
+        bool abone_wchar;
+
         // 右ペーンが空の時にサイドバーを閉じるか
         bool expand_sidebar;
 
         // 3ペーン時にスレ一覧やスレビューを最大化するか
         bool expand_rpane;
 
+        // ペーンの境界をクリックしてサイドバーを開け閉めする
+        bool open_sidebar_by_click;
+
         // 次スレ検索の類似度のしきい値
         int threshold_next;
 
         // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-        bool replace_favorite_next;
+        int replace_favorite_next;
 
         // お気に入りの自動更新をするかダイアログを出す
         bool show_diag_replace_favorite;
@@ -397,15 +461,36 @@ namespace CONFIG
         // 起動時にお気に入りを自動でチェックする
         bool check_update_boot;
 
+        // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示  2: 登録しない )
+        int check_favorite_dup;
+
+        // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+        int show_favorite_select_diag;
+
         // Ctrl+qでウィンドウを閉じない
         bool disable_close;
 
+        // メニューバーを非表示にした時にダイアログを表示
+        bool show_hide_menubar_diag;
+
+        // 状態変更時にメインステータスバーの色を変える
+        bool change_stastatus_color;
+
         // まちBBSの取得に offlaw.cgi を使用する
         bool use_machi_offlaw;
 
         // 書き込み履歴のあるスレを削除する時にダイアログを表示
         bool show_del_written_thread_diag;
 
+        // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+        int delete_img_in_thread;
+
+        // FIFOの作成などにエラーがあったらダイアログを表示する
+        bool show_diag_fifo_error;
+
+        // 指定した分ごとにセッションを自動保存 (0: 保存しない)
+        int save_session;
+        
 #ifdef HAVE_MIGEMO_H
         // migemo-dictの場所
         std::string migemodict_path;
