@@ -93,6 +93,9 @@ namespace CONFIG
     // p2の認証サーバのアドレス
     const std::string& get_url_loginp2();
 
+    // BEの認証サーバのアドレス
+    const std::string& get_url_loginbe();
+
     // bbsmenu.htmlのURL
     const std::string& get_url_bbsmenu();    
 
@@ -174,6 +177,13 @@ namespace CONFIG
     // 同一ホストに対する最大コネクション数( 1 または 2 )
     const int get_connection_num();
 
+    // 2chのクッキー:HAP
+    const bool get_use_cookie_hap();
+    const std::string& get_cookie_hap();
+    const std::string& get_cookie_hap_bbspink();
+    void set_cookie_hap( const std::string& cookie_hap );
+    void set_cookie_hap_bbspink( const std::string& cookie_hap );
+
     // リンクをクリックしたときに実行するコマンド
     const std::string& get_command_openurl();
     void set_command_openurl( const std::string& command );
@@ -306,6 +316,12 @@ namespace CONFIG
     // お気に入りでカテゴリを常にひとつだけ開く
     const bool get_open_one_favorite();
 
+    // デフォルトの書き込み名
+    const std::string get_write_name();
+
+    // デフォルトのメールアドレス
+    const std::string get_write_mail();
+
     // 書き込み時に書き込み確認ダイアログを出すかどうか
     const bool get_always_write_ok();
     void set_always_write_ok( const bool write_ok );
@@ -468,6 +484,13 @@ namespace CONFIG
     const bool get_abone_chain();
     void set_abone_chain( const bool set );
 
+    // NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+    const bool get_abone_icase();
+    void set_abone_icase( const bool set );
+
+    const bool get_abone_wchar();
+    void set_abone_wchar( const bool set );
+
     // 右ペーンが空の時にサイドバーを閉じるか
     const bool get_expand_sidebar();
 
@@ -511,6 +534,9 @@ namespace CONFIG
     const bool get_show_hide_menubar_diag();
     void set_show_hide_menubar_diag( const bool set );
 
+    // 状態変更時にメインステータスバーの色を変える
+    const bool get_change_stastatus_color();
+
     // まちBBSの取得に offlaw.cgi を使用する
     const bool get_use_machi_offlaw();
     void set_use_machi_offlaw( const bool set );
