@@ -36,6 +36,8 @@ namespace CONTROL
 #define KEYCONF_TabNum8 "Alt+8"
 #define KEYCONF_TabNum9 "Alt+9"
 
+#define KEYCONF_RestoreLastTab "Ctrl+T"
+
 #define KEYCONF_PreBookMark  "Ctrl+F2"
 #define KEYCONF_NextBookMark  "F2"
 
@@ -53,6 +55,9 @@ namespace CONTROL
 #define KEYCONF_PageUp  "Page_Up KP_Prior"
 #define KEYCONF_PageDown  "Page_Down KP_Next"
 
+#define KEYCONF_PrevDir  "{"
+#define KEYCONF_NextDir  "}"
+
 #define KEYCONF_Home  "Home g < KP_Home"
 #define KEYCONF_End  "End G > KP_End"
 
@@ -65,6 +70,7 @@ namespace CONTROL
 #define KEYCONF_Save  "Ctrl+s"
 #define KEYCONF_Delete  "Delete KP_Delete"
 #define KEYCONF_Reload  "F5 s"
+#define KEYCONF_ReloadArticle  "Shift+F5 S"
 #define KEYCONF_StopLoading  "Escape"
 #define KEYCONF_OpenURL "Ctrl+o"
 #define KEYCONF_Copy  "Ctrl+c"
@@ -134,6 +140,7 @@ namespace CONTROL
 #define KEYCONF_ExecWrite  "Alt+w" 
 
 #define KEYCONF_FocusWrite  "Tab" 
+#define KEYCONF_ToggleSage  "Alt+s" 
 
 // EDIT
 #define KEYCONF_HomeEdit  ""
@@ -147,6 +154,7 @@ namespace CONTROL
 #define KEYCONF_DeleteEdit  ""
 #define KEYCONF_BackspEdit  ""
 #define KEYCONF_UndoEdit  "Ctrl+/ Ctrl+z"
+#define KEYCONF_EnterEdit  ""
 
 #define KEYCONF_InputAA  "Alt+a"
 
@@ -172,18 +180,34 @@ namespace CONTROL
 #define MOUSECONF_TabRightUpdated ""
 #define MOUSECONF_TabLeftUpdated ""
 
+#define MOUSECONF_CloseAllTabs ""
+#define MOUSECONF_CloseOtherTabs ""
+
+#define MOUSECONF_RestoreLastTab "64"
+
+#define MOUSECONF_CheckUpdateTabs ""
+
 #define MOUSECONF_ToggleArticle "2"
 #define MOUSECONF_ShowSideBar  ""
+#define MOUSECONF_ShowMenuBar ""
+#define MOUSECONF_ShowToolBarMain ""
 #define MOUSECONF_Home "68"
 #define MOUSECONF_End "62"
 #define MOUSECONF_Quit "26"
 #define MOUSECONF_Reload "82"
 #define MOUSECONF_StopLoading "8"
+#define MOUSECONF_AppendFavorite  ""
+
 #define MOUSECONF_NewArticle "24"
 #define MOUSECONF_WriteMessage "24"
+
 #define MOUSECONF_CheckUpdateRoot "48"
 #define MOUSECONF_CheckUpdateOpenRoot "42"
 
+#define MOUSECONF_QuitJD ""
+#define MOUSECONF_MaximizeMainWin ""
+#define MOUSECONF_IconifyMainWin ""
+
 // ARTICLE
 #define MOUSECONF_GotoNew "626"
 #define MOUSECONF_SearchNextArticle "28"
@@ -256,6 +280,8 @@ namespace CONTROL
 #define BUTTONCONF_CloseImageButton "Mid"
 #define BUTTONCONF_ScrollImageButton "Left"
 #define BUTTONCONF_CancelMosaicButton ""
+#define BUTTONCONF_SaveImageButton ""
+#define BUTTONCONF_ResizeImageButton "Left"
 
 }
 
