@@ -22,20 +22,12 @@
 using namespace DBTREE;
 
 
-enum
-{
-    DEFAULT_NUMBER_MAX_2CH = 1000  // 規定の最大レス数
-};
-
-
 Board2ch::Board2ch( const std::string& root, const std::string& path_board, const std::string& name )
     : Board2chCompati( root, path_board, name, std::string() )
 {
 #ifdef _DEBUG
     std::cout << "Board2ch::Board2ch\n";
 #endif
-
-    set_number_max_res( DEFAULT_NUMBER_MAX_2CH );
 }
 
 
@@ -44,7 +36,14 @@ Board2ch::~Board2ch()
 
 
 // ユーザエージェント
+// ダウンロード用
 const std::string& Board2ch::get_agent()
+{
+    return CONFIG::get_agent_for2ch();
+}
+
+// 書き込み用
+const std::string& Board2ch::get_agent_w()
 {
     if( CORE::get_loginp2()->login_now() ) return CONFIG::get_agent_for_data();
 
@@ -151,7 +150,7 @@ const std::string Board2ch::cookie_for_write()
     // BE ログイン中
     else if( CORE::get_loginbe()->login_now() ){
         if( ! cookie.empty() ) cookie += "; ";
-        cookie += "DMDM=" + CORE::get_loginbe()->get_username() + "; MDMD=" + CORE::get_loginbe()->get_passwd();
+        cookie += "DMDM=" + CORE::get_loginbe()->get_sessionid() + "; MDMD=" + CORE::get_loginbe()->get_sessiondata();
     }
 
 #ifdef _DEBUG
@@ -208,7 +207,7 @@ const std::string Board2ch::create_newarticle_message( const std::string& subjec
                 << "&popup=1"
                 << "&rescount=1"
                 << "&ttitle_en="
-                << "&csrfid=" << MISC::url_encode( CORE::get_loginp2()->get_csrfid() )
+                << "&csrfid=" << MISC::url_encode( CORE::get_loginp2()->get_sessiondata() )
                 << "&newthread=1";
     }
 
@@ -270,3 +269,66 @@ ArticleBase* Board2ch::append_article( const std::string& datbase, const std::st
 }
 
 
+
+// 2chのクッキー:HAP
+const std::string Board2ch::get_hap()
+{
+    if( ! CONFIG::get_use_cookie_hap() ) return std::string();
+
+    if( get_root().find( ".bbspink.com" ) != std::string::npos ) return CONFIG::get_cookie_hap_bbspink();
+    return CONFIG::get_cookie_hap();
+}
+
+void Board2ch::set_hap( const std::string& hap )
+{
+    if( ! CONFIG::get_use_cookie_hap() )  return;
+
+    if( get_root().find( ".bbspink.com" ) != std::string::npos ) CONFIG::set_cookie_hap_bbspink( hap );
+    else CONFIG::set_cookie_hap( hap );
+}
+
+
+//
+// 2chのクッキー:HAPの更新
+//
+void Board2ch::update_hap()
+{
+    if( ! CONFIG::get_use_cookie_hap() ) return;
+
+    const std::list< std::string > list_cookies = BoardBase::list_cookies_for_write();
+    if( list_cookies.empty() ) return;
+
+#ifdef _DEBUG
+    std::cout << "Board2ch::update_hap\n";
+#endif
+
+    JDLIB::Regex regex;
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    const std::string query_hap = "HAP=([^;]*)?";
+
+    std::list< std::string >::const_iterator it = list_cookies.begin();
+    for( ; it != list_cookies.end(); ++it ){
+
+        const std::string cookie = (*it);
+#ifdef _DEBUG
+        std::cout << cookie << std::endl;
+#endif
+        if( regex.exec( query_hap, cookie, offset, icase, newline, usemigemo, wchar ) ){
+
+            const std::string tmp_hap = regex.str( 1 );
+            if( ! tmp_hap.empty() && tmp_hap != get_hap() ){
+#ifdef _DEBUG
+                std::cout << "old = " << get_hap() << std::endl;
+                std::cout << "new = " << tmp_hap << std::endl;
+#endif
+                set_hap( tmp_hap );
+                return;
+            }
+        }
+    }
+}
