@@ -11,10 +11,14 @@
 
 #include "dbimg/img.h"
 
+#include "jdlib/miscutil.h"
+
 #include "config/globalconf.h"
 
 #include "control/controlid.h"
 
+#include "history/historymanager.h"
+
 #include "command.h"
 #include "httpcode.h"
 #include "session.h"
@@ -44,7 +48,9 @@ ImageViewMain::ImageViewMain( const std::string& url )
       m_scrwin( 0 ),
       m_length_prev( 0 ),
       m_show_status( false ),
-      m_show_label( false )
+      m_show_label( false ),
+      m_do_resizing( false ),
+      m_scrolled( false )
 {
 #ifdef _DEBUG    
     std::cout << "ImageViewMain::ImageViewMain : " << get_url() << std::endl;
@@ -70,9 +76,20 @@ ImageViewMain::ImageViewMain( const std::string& url )
 }
 
 
+ImageViewMain::~ImageViewMain()
+{
+    // 閉じた画像履歴更新
+    HISTORY::append_history( URL_HISTCLOSEIMGVIEW,
+                             get_url(),
+                             MISC::get_filename( get_url() ), TYPE_IMAGE );
+}
+
+
 //
 // クロック入力
 //
+// アクティブ(表示されている)view以外にはクロックは来ないのに注意
+//
 void ImageViewMain::clock_in()
 {
     View::clock_in();
@@ -86,14 +103,35 @@ void ImageViewMain::clock_in()
         IMAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
     }
 
+    // ロード待ち
+    if( is_wait() ){
+
+        // ロード待ち状態解除
+        if( ! get_img()->is_wait() ){
+
+            set_wait( false );
+
+            if( get_img()->is_loading() ){
+                set_loading( true  ); 
+                set_status( "読み込み中" );
+                if( m_show_label ) m_label.set_text( get_status() );
+            }
+
+            else{
+                set_loading( false );
+                show_view();
+                show_status();
+            }
+        }
+    }
+
     // ロード中
-    if( is_loading() ){
+    else if( is_loading() ){
 
         // 読み込みサイズの表示更新
         if( get_img()->is_loading() ) show_status();
 
         // ロード完了
-        // 次にclock_in()が呼ばれたら下のelseの中に入る
         else{
 
             set_loading( false ); 
@@ -208,6 +246,7 @@ void ImageViewMain::remove_label()
 void ImageViewMain::show_view()
 {
     if( is_loading() ) return;
+    if( is_wait() ) return;
 
 #ifdef _DEBUG
     std::cout << "ImageViewMain::show_view url = " << get_url() << std::endl;
@@ -231,15 +270,26 @@ void ImageViewMain::show_view()
 
     remove_label();
 
-    // 読み込み中        
-    if( get_img()->is_loading() ){
+    // ロード待ち、又は読み込み中        
+    if( get_img()->is_wait() || get_img()->is_loading() ){
 
+        if( get_img()->is_wait() ){
 #ifdef _DEBUG
-        std::cout << "now loading\n";
-#endif    
-        set_loading( true );
+            std::cout << "wait\n";
+#endif
+            set_wait( true );
+            set_loading( false );
+            set_status( "待機中" );
+        }
+        else{
+#ifdef _DEBUG
+            std::cout << "loading\n";
+#endif
+            set_wait( false );
+            set_loading( true );
+            set_status( "読み込み中" );
+        }
         m_length_prev = 0;
-        set_status( "loading..." );
         m_show_status = true; // viewがアクティブになった時点でステータス表示
 
         set_label();
@@ -258,7 +308,9 @@ void ImageViewMain::show_view()
     // エラー
     else{
 
-        set_status( get_img()->get_str_code() );
+        if( ! get_img()->get_str_code().empty() ) set_status( get_img()->get_str_code() );
+        else set_status( "画像情報が存在しません。再読み込みして下さい" );
+
         m_show_status = true; // viewがアクティブになった時点でステータス表示
 
         set_label();
@@ -274,7 +326,7 @@ void ImageViewMain::show_view()
 //
 void ImageViewMain::show_status()
 {
-    if( ! is_loading() ){
+    if( ! is_loading() && ! is_wait() ){
 
         // 画像が表示されていたら画像情報
         if( get_imagearea() ){
@@ -283,7 +335,7 @@ void ImageViewMain::show_status()
             ss << get_img()->get_width() << " x " << get_img()->get_height();
             if( get_img()->get_width() )
                 ss << " (" << get_img()->get_size() << " %)";
-            ss << " " << get_img()->total_length()/1024 << " kb ";
+            ss << " " << get_img()->total_length()/1024 << " K ";
             if( get_img()->is_protected() ) ss << " キャッシュ保護されています";
 
             set_status( ss.str() );
@@ -292,8 +344,7 @@ void ImageViewMain::show_status()
         // エラー(ネットワーク系)
         else if( get_img()->get_code() != HTTP_OK ) set_status( get_img()->get_str_code() );
 
-        // ステータス標示
-        IMAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+        m_show_status = true; // viewがアクティブになった時点でステータス表示
         if( m_show_label ) m_label.set_text( get_status() );
 
 #ifdef _DEBUG
@@ -302,7 +353,7 @@ void ImageViewMain::show_status()
     }
 
     // ロード中
-    else{
+    else if( is_loading() ){
 
         // 読み込みサイズが更新した場合
         if( m_length_prev != get_img()->current_length() ){
@@ -313,8 +364,7 @@ void ImageViewMain::show_status()
             snprintf( tmpstr, 256, "%zd k / %zd k", m_length_prev/1024, get_img()->total_length()/1024 );
             set_status( tmpstr );
 
-            // ステータス標示
-            IMAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+            m_show_status = true; // viewがアクティブになった時点でステータス表示
             if( m_show_label ) m_label.set_text( get_status() );
 
 #ifdef _DEBUG
@@ -348,6 +398,12 @@ bool ImageViewMain::slot_button_press( GdkEventButton* event )
     // ドラッグして画像移動するときの起点
     m_x_motion = event->x_root;
     m_y_motion = event->y_root;
+    m_scrolled = false;
+
+    // ボタンをリリースした時に大きさを変更
+    m_do_resizing = false;
+    if( ! is_loading() && ! is_wait()
+        && get_control().button_alloted( event, CONTROL::ResizeImageButton ) ) m_do_resizing = true;
 
     return true;
 }
@@ -395,6 +451,8 @@ bool ImageViewMain::slot_motion_notify( GdkEventMotion* event )
 
             if( vadj ) vadj->set_value(
                 MAX( vadj->get_lower(), MIN( vadj->get_upper() - vadj->get_page_size(), vadj->get_value() - dy ) ) );
+
+            m_scrolled = true;
         }
     }
 
@@ -462,3 +520,28 @@ void ImageViewMain::scroll_right()
     hadjust->set_value(  MIN( hadjust->get_upper() - hadjust->get_page_size(),
                               hadjust->get_value() + hadjust->get_step_increment() ) );
 }
+
+
+//
+// viewの操作
+//
+const bool ImageViewMain::operate_view( const int control )
+{
+    // スクロールしたときはキャンセル
+    if( m_scrolled ){
+        m_scrolled = false;
+        return false;
+    }
+
+    int cntl = control;
+
+    if( m_do_resizing ){
+
+        m_do_resizing = false;
+
+        if( get_img()->get_size() == 100 ) cntl = CONTROL::ZoomFitImage;
+        else cntl = CONTROL::OrgSizeImage;
+    }
+
+    return ImageViewBase::operate_view( cntl );
+}
