@@ -16,6 +16,7 @@
 #include "fontid.h"
 #include "colorid.h"
 #include "global.h"
+#include "sharedbuffer.h"
 
 #include "linkfiltermanager.h"
 #include "prefdiagfactory.h"
@@ -156,15 +157,6 @@ void Core::slot_reload_list()
 }
 
 
-//
-// お気に入り保存
-//
-void Core::slot_save_favorite()
-{
-    CORE::core_set_command( "save_favorite","" );
-}
-
-
 //
 // 終了
 //
@@ -186,6 +178,7 @@ void Core::slot_toggle_since( const int mode )
 #endif
 
     SESSION::set_col_since_time( mode );
+    DBTREE::reset_all_since_date();
     BOARD::get_admin()->set_command( "relayout_all" );    
 }
 
@@ -202,12 +195,30 @@ void Core::slot_toggle_write( const int mode )
 #endif
 
     SESSION::set_col_write_time( mode );
+    DBTREE::reset_all_write_date();
     BOARD::get_admin()->set_command( "relayout_all" );    
 }
 
 
 //
-// ツールバーの表示モード
+// メインツールバー表示切り替え
+//
+void Core::slot_toggle_toolbarmain()
+{
+    if( SESSION::is_booting() ) return;
+    if( ! m_enable_menuslot ) return;
+
+    pack_widget( true );
+    SESSION::set_show_main_toolbar( ! SESSION::get_show_main_toolbar() );
+    pack_widget( false );
+
+    restore_focus( true, false );
+
+}
+
+
+//
+// メインツールバーの表示位置
 //
 void Core::slot_toggle_toolbarpos( const int pos )
 {
@@ -215,18 +226,18 @@ void Core::slot_toggle_toolbarpos( const int pos )
     if( ! m_enable_menuslot ) return;
 
 #ifdef _DEBUG
-    std::cout << "Core::slot_toggle_toolbarpos pos = " << pos << " / " << SESSION::toolbar_pos() << std::endl;
+    std::cout << "Core::slot_toggle_toolbarpos pos = " << pos << " / " << SESSION::get_toolbar_pos() << std::endl;
 #endif
 
-    pack_widget( true );
+    if( ! SESSION::get_show_main_toolbar() ) SESSION::set_toolbar_pos( pos );
+    else{
 
-    // 表示切り替え
-    if( SESSION::toolbar_pos() == pos ) SESSION::set_toolbar_pos( SESSION::TOOLBAR_POS_NOT ); // 隠す
-    else SESSION::set_toolbar_pos( pos );
+        pack_widget( true );
+        SESSION::set_toolbar_pos( pos );
+        pack_widget( false );
 
-    pack_widget( false );
-
-    restore_focus( true, false );
+        restore_focus( true, false );
+    }
 }
 
 
@@ -341,6 +352,18 @@ void Core::slot_toggle_v3pane()
 }
 
 
+//
+// フルスクリーン
+//
+void Core::slot_toggle_fullscreen()
+{
+    if( ! m_enable_menuslot ) return;
+
+    if( SESSION::is_full_win_main() ) m_win_main.unfullscreen();
+    else m_win_main.fullscreen();
+}
+
+
 //
 // messageビューをウィンドウ表示
 //
@@ -367,6 +390,15 @@ void Core::slot_toggle_embmsg()
 }
 
 
+//
+// messgeビューのwrap切り替え
+//
+void Core::slot_toggle_msg_wrap()
+{
+    CORE::core_set_command( "toggle_message_wrap", "" );
+}
+
+
 //
 // imageビュー表示設定
 //
@@ -495,6 +527,17 @@ void Core::slot_setup_msgitem()
 }
 
 
+
+//
+// コンテキストメニュー(スレ一覧)の表示項目
+//
+void Core::slot_setup_boarditem_menu()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARDITEM_MENU, "" );
+    pref->run();
+    delete pref;
+}
+
 //
 // コンテキストメニュー(スレビュー)の表示項目
 //
@@ -506,6 +549,15 @@ void Core::slot_setup_articleitem_menu()
 }
 
 
+//
+// 板一覧のプロパティ
+//
+void Core::slot_bbslist_pref()
+{
+    BBSLIST::get_admin()->set_command( "show_preferences", URL_BBSLISTVIEW );
+}
+
+
 //
 // スレ一覧のプロパティ
 //
@@ -532,18 +584,6 @@ void Core::slot_image_pref()
 }
 
 
-//
-// 過去ログ表示切替え
-//
-void Core::slot_toggle_oldarticle()
-{
-    CONFIG::set_show_oldarticle( ! CONFIG::get_show_oldarticle() );
-
-    SKELETON::MsgDiag mdiag( NULL, "次に開いた板から有効になります" );
-    mdiag.run();
-}
-
-
 //
 // 起動時にviewを復元
 //
@@ -894,7 +934,7 @@ void Core::slot_setup_abone_thread()
 //
 void Core::slot_toggle_abone_transp_chain()
 {
-    bool status = CONFIG::get_abone_chain() & CONFIG::get_abone_transparent();
+    const bool status = CONFIG::get_abone_chain() & CONFIG::get_abone_transparent();
 
     CONFIG::set_abone_transparent( ! status );
     CONFIG::set_abone_chain( ! status );
@@ -905,6 +945,24 @@ void Core::slot_toggle_abone_transp_chain()
 }
 
 
+//
+// NG正規表現によるあぼーん時に大小と全半角文字の違いを無視する
+//
+void Core::slot_toggle_abone_icase_wchar()
+{
+    const bool status = CONFIG::get_abone_icase() & CONFIG::get_abone_wchar();
+
+    CONFIG::set_abone_icase( ! status );
+    CONFIG::set_abone_wchar( ! status );
+
+    // あぼーん情報更新
+    DBTREE::update_abone_thread();
+
+    DBTREE::update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+
 // 実況設定
 void Core::slot_setup_live()
 {
@@ -1018,8 +1076,8 @@ void Core::slot_live_start_stop()
 //
 void Core::slot_search_cache_board()
 {
-    std::string url = BOARD::get_admin()->get_current_url();
-    if( ! url.empty() ) CORE::core_set_command( "open_article_searchlog", url );
+    const std::string url = BOARD::get_admin()->get_current_url();
+    if( ! url.empty() ) CORE::core_set_command( "open_article_searchlog", url, "", "noexec" );
 }
 
 
@@ -1028,7 +1086,7 @@ void Core::slot_search_cache_board()
 //
 void Core::slot_search_cache()
 {
-    CORE::core_set_command( "open_article_searchalllog" );
+    CORE::core_set_command( "open_article_searchlog", URL_SEARCH_ALLBOARD, "", "noexec" );
 }
 
 
@@ -1037,7 +1095,7 @@ void Core::slot_search_cache()
 //
 void Core::slot_show_cache_board()
 {
-    std::string url = DBTREE::url_subject( BOARD::get_admin()->get_current_url() );
+    const std::string url = DBTREE::url_subject( BOARD::get_admin()->get_current_url() );
     if( ! url.empty() ) CORE::core_set_command( "open_board_showlog", url );
 }
 
@@ -1056,7 +1114,7 @@ void Core::slot_show_cache()
 //
 void Core::slot_search_title()
 {
-    CORE::core_set_command( "open_article_searchtitle" );
+    CORE::core_set_command( "open_article_searchtitle", "", "", "noexec" );
 }
 
 
@@ -1120,6 +1178,46 @@ void Core::slot_import_dat()
 }
 
 
+//
+// サイドバーをスレ一覧に表示
+//
+void Core::slot_show_sidebarboard()
+{
+    if( SESSION::get_sidebar_current_url() != URL_BBSLISTVIEW
+        && SESSION::get_sidebar_current_url() != URL_HISTBOARDVIEW
+        ){
+
+        const std::string tab = "left";
+        const std::string mode = "";
+        CORE::core_set_command( "open_sidebar_board", SESSION::get_sidebar_current_url(), tab, mode, "0" );
+    }
+}
+
+
+//
+// サイドバーの仮想板を作成
+//
+void Core::slot_create_vboard()
+{
+    if( SESSION::get_sidebar_current_url() != URL_BBSLISTVIEW
+        && SESSION::get_sidebar_current_url() != URL_HISTBOARDVIEW
+        ){
+
+        CORE::DATA_INFO_LIST list_info;
+        CORE::DATA_INFO info;
+        info.type = TYPE_VBOARD;
+        info.parent = CORE::get_mainwindow();
+        info.url = SESSION::get_sidebar_current_url() + SIDEBAR_SIGN + "0";
+        info.name = SESSION::get_sidebar_dirname( SESSION::get_sidebar_current_url(), 0 );
+        info.path = Gtk::TreePath( "0" ).to_string();
+        list_info.push_back( info );
+        CORE::SBUF_set_list( list_info );
+
+        CORE::core_set_command( "append_favorite", URL_FAVORITEVIEW );
+    }
+}
+
+
 //
 // サポートBBS
 //
