@@ -12,11 +12,13 @@
 #include "skeleton/msgdiag.h"
 #include "skeleton/label_entry.h"
 #include "skeleton/editview.h"
+#include "skeleton/detaildiag.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
 #include "jdlib/misctrip.h"
 #include "jdlib/jdiconv.h"
+#include "jdlib/jdregex.h"
 
 #include "dbtree/interface.h"
 
@@ -66,7 +68,11 @@ MessageViewBase::MessageViewBase( const std::string& url )
       m_entry_mail( CORE::COMP_MAIL ),
       m_text_message( NULL ),
       m_enable_focus( true ),
-      m_counter( 0 )
+      m_lng_str_enc( 0 ),
+      m_counter( 0 ),
+      m_text_changed( false ),
+      m_over_lines( false ),
+      m_over_lng( false )
 {
 #ifdef _DEBUG
     std::cout << "MessageViewBase::MessageViewBase " << get_url() << std::endl;
@@ -159,12 +165,32 @@ void MessageViewBase::clock_in()
         // 書き込み規制経過時刻表示
         time_t left = DBTREE::board_write_leftsec( get_url() );
         if( left ){
-            m_str_pass = "  ( 書込規制中 残り " + MISC::itostr( left ) + " 秒 )";
-            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() + m_str_pass );
+
+            bool set_color = false;
+            if( m_str_pass.empty() ) set_color = true;
+
+            m_str_pass = "規制中 " + MISC::itostr( left ) + " 秒 ";
+
+            std::string force;
+            if( SESSION::focused_admin() == SESSION::FOCUS_MESSAGE ) force = "force";
+            MESSAGE::get_admin()->set_command( "set_title", get_url(), m_str_pass + get_title(), force );
+            MESSAGE::get_admin()->set_command( "set_status", get_url(), m_str_pass + get_status(), force );
+
+            if( set_color ){
+                MESSAGE::get_admin()->set_command( "redraw_toolbar" );
+                MESSAGE::get_admin()->set_command( "set_status_color", get_url(), get_color(), force );
+            }
         }
         else if( ! m_str_pass.empty() ){
+
             m_str_pass = std::string();
-            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+            std::string force;
+            if( SESSION::focused_admin() == SESSION::FOCUS_MESSAGE ) force = "force";
+            MESSAGE::get_admin()->set_command( "set_title", get_url(), get_title(), force );
+            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status(), force );
+
+            MESSAGE::get_admin()->set_command( "redraw_toolbar" );
+            MESSAGE::get_admin()->set_command( "set_status_color", get_url(), get_color(), force );
         }
     }
 }
@@ -253,7 +279,10 @@ const bool MessageViewBase::set_command( const std::string& command, const std::
     // メッセージをクリア
     else if( command == "clear_message" ){
 
-        if( m_text_message ) m_text_message->set_text( std::string() );
+        if( m_text_message ){
+            m_text_message->set_text( std::string() );
+            m_text_message->clear_undo();
+        }
 
         if( m_notebook.get_current_page() != PAGE_MESSAGE ){
             m_enable_focus = false;
@@ -269,7 +298,7 @@ const bool MessageViewBase::set_command( const std::string& command, const std::
     }
 
     // メッセージ保存
-    else if ( "save_message" )
+    else if( command == "save_message" )
     {
         if( ! get_message().empty() ){
 
@@ -291,6 +320,9 @@ const bool MessageViewBase::set_command( const std::string& command, const std::
         }
     }
 
+    // ビューの wrap 切り替え
+    else if( command == "toggle_wrap" ) set_wrap();
+
     return false;
 }
 
@@ -318,6 +350,53 @@ void MessageViewBase::save_name()
 }
 
 
+//
+// 名前欄に名前をセット
+//
+void MessageViewBase::set_name()
+{
+    // スレ別の名前
+    if( DBTREE::write_fixname( get_url() ) ){
+        m_check_fixname.set_active();
+        m_entry_name.set_text( DBTREE::write_name( get_url() ) );
+    }
+    // スレ別の名前が設定されていなかったら板別の名前
+    else if( ! DBTREE::board_get_write_name( get_url() ).empty() ){
+
+        std::string tmpname = DBTREE::board_get_write_name( get_url() );
+
+        // 空白セット
+        if( tmpname == JD_NAME_BLANK ) m_entry_name.set_text( std::string() );
+        else m_entry_name.set_text( tmpname );
+    }
+    // デフォルトをセット
+    else m_entry_name.set_text( CONFIG::get_write_name() );
+}
+
+
+//
+// メール欄にアドレスをセット
+//
+void MessageViewBase::set_mail()
+{
+    // スレ別のメール
+    if( DBTREE::write_fixmail( get_url() ) ){
+        m_check_fixmail.set_active();
+        m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
+    }
+    // スレ別の名前が設定されていなかったら板別のメール
+    else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
+
+        std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
+
+        // 空白セット
+        if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
+        else m_entry_mail.set_text( tmpmail );
+    }
+    // デフォルトをセット
+    else m_entry_mail.set_text( CONFIG::get_write_mail() );
+}
+
 
 //
 // ツールバーなどのパック
@@ -336,32 +415,8 @@ void MessageViewBase::pack_widget()
     m_tooltip.set_tip( m_check_fixname, "チェックすると名前欄を保存して固定にする" );
     m_tooltip.set_tip( m_check_fixmail, "チェックするとメール欄を保存して固定にする" );
 
-    // スレ別の名前
-    if( DBTREE::write_fixname( get_url() ) ){
-        m_check_fixname.set_active();
-        m_entry_name.set_text( DBTREE::write_name( get_url() ) );
-    }
-    // スレ別の名前が設定されていなかったら板別の名前
-    else if( ! DBTREE::board_get_write_name( get_url() ).empty() ){
-        m_entry_name.set_text( DBTREE::board_get_write_name( get_url() ) );
-    }
-
-    // スレ別のメール
-    if( DBTREE::write_fixmail( get_url() ) ){
-        m_check_fixmail.set_active();
-        m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
-    }
-    // スレ別の名前が設定されていなかったら板別のメール
-    else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
-
-        std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
-
-        // 空白セット
-        if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
-        else m_entry_mail.set_text( tmpmail );
-    }
-    // デフォルトはsage
-    else m_entry_mail.set_text( "sage" );
+    set_name();
+    set_mail();
 
     m_tool_name.add( m_label_name );
     m_tool_mail.add( m_label_mail );
@@ -393,15 +448,20 @@ void MessageViewBase::pack_widget()
 
             m_text_message = MESSAGE::get_admin()->get_text_message();
             m_text_message->set_text( std::string() );
+            m_text_message->clear_undo();
         }
         else m_text_message = Gtk::manage( new SKELETON::EditView() );
     }
-    m_msgview.pack_start( *m_text_message );
+
+    set_wrap();
+
+    if( m_text_message->get_parent() ) m_text_message->reparent( m_msgview );
+    else m_msgview.pack_start( *m_text_message );
 
     m_text_message->set_accepts_tab( false );
     m_text_message->sig_key_press().connect( sigc::mem_fun(*this, &MessageViewBase::slot_key_press ) );    
     m_text_message->sig_button_press().connect( sigc::mem_fun(*this, &MessageViewBase::slot_button_press ) );
-    m_text_message->get_buffer()->signal_changed().connect( sigc::mem_fun(*this, &MessageViewBase::show_status ) );
+    m_text_message->get_buffer()->signal_changed().connect( sigc::mem_fun(*this, &MessageViewBase::slot_text_changed ) );
 
     // プレビュー
     m_preview = CORE::ViewFactory( CORE::VIEW_ARTICLEPREVIEW, get_url() );
@@ -426,6 +486,17 @@ void MessageViewBase::pack_widget()
 }
 
 
+//
+// テキストの折り返し
+//
+void MessageViewBase::set_wrap()
+{
+    if( ! m_text_message ) return;
+
+    if( CONFIG::get_message_wrap() ) m_text_message->set_wrap_mode( Gtk::WRAP_CHAR );
+    else m_text_message->set_wrap_mode( Gtk::WRAP_NONE );
+}
+
 
 //
 // 再描画
@@ -467,7 +538,7 @@ const bool MessageViewBase::operate_view( const int control )
             MESSAGE::get_admin()->set_command( "toolbar_write", get_url() );
             break;
 
-        case CONTROL::TabLeft:
+       case CONTROL::TabLeft:
         case CONTROL::TabLeftUpdated:
             MESSAGE::get_admin()->set_command( "tab_left" );
             break;
@@ -477,41 +548,9 @@ const bool MessageViewBase::operate_view( const int control )
             MESSAGE::get_admin()->set_command( "tab_right" );
             break;
 
-        // タブ位置(1-9)で移動
-        case CONTROL::TabNum1:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "1" );
-            break;
-
-        case CONTROL::TabNum2:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "2" );
-            break;
-
-        case CONTROL::TabNum3:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "3" );
-            break;
-
-        case CONTROL::TabNum4:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "4" );
-            break;
-
-        case CONTROL::TabNum5:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "5" );
-            break;
-
-        case CONTROL::TabNum6:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "6" );
-            break;
-
-        case CONTROL::TabNum7:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "7" );
-            break;
-
-        case CONTROL::TabNum8:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "8" );
-            break;
-
-        case CONTROL::TabNum9:
-            MESSAGE::get_admin()->set_command( "tab_num", "", "9" );
+        case CONTROL::ToggleSage:
+            if( m_entry_mail.get_text() == "sage" ) m_entry_mail.set_text( "" );
+            else set_mail();
             break;
 
             // 書き込みボタンにフォーカスを移す
@@ -547,8 +586,7 @@ void MessageViewBase::write()
     }
 
     if( m_post && m_post->is_loading() ){
-        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み中です" );
-        mdiag.run();
+        m_post->show_writingdiag( true );
         return;
     }
 
@@ -587,7 +625,28 @@ void MessageViewBase::write()
         }
     }
 
-    write_impl();
+    const std::string msg = create_message();
+    if( msg.empty() ) return;
+
+    // 数値文字参照(&#????;)書き込み可能か
+    if( DBTREE::get_unicode( get_url() ) == "change" ){
+
+        JDLIB::Regex regex;
+        const size_t offset = 0;
+        const bool icase = false;
+        const bool newline = true;
+        const bool usemigemo = false;
+        const bool wchar = false;
+        if( regex.exec( "%26%23[0-9]*%3b", msg, offset, icase, newline, usemigemo, wchar ) ){
+
+            SKELETON::MsgDiag mdiag( get_parent_win(),
+                                     "ユニコード文字が含まれていますが、この板ではユニコード文字は文字化けします(BBS_UNICODE=change)。\n\n書き込みますか？",
+                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+        }
+    }
+
+    write_impl( msg );
 }
 
 
@@ -760,11 +819,14 @@ void MessageViewBase::post_fin()
 
     // 成功
     if( code == HTTP_OK
-        || ( code == HTTP_REDIRECT && ! location.empty() ) // (まちBBSなどで)リダイレクトした場合
+        || ( ( code == HTTP_MOVED_PERM || code == HTTP_REDIRECT ) && ! location.empty() ) // (まちBBSなどで)リダイレクトした場合
         ){
         save_postlog();
 
-        if( m_text_message ) m_text_message->set_text( std::string() );
+        if( m_text_message ){
+            m_text_message->set_text( std::string() );
+            m_text_message->clear_undo();
+        }
 
         close_view();
 
@@ -782,9 +844,13 @@ void MessageViewBase::post_fin()
     // 失敗
     else if( code != HTTP_CANCEL ){
 
-        SKELETON::MsgDiag mdiag( get_parent_win(),
-                                 "書き込みに失敗しました\n\n" + m_post->errmsg(), false, Gtk::MESSAGE_ERROR  );
-        mdiag.run();
+        SKELETON::DetailDiag ddiag( get_parent_win(), get_url(),
+                          false,
+                          "書き込みに失敗しました\n\n" + m_post->get_errmsg(), "概要",
+                          m_post->get_return_html(), "詳細" );
+
+        ddiag.set_title( "書き込みエラー" );
+        ddiag.run();
     }
 }
 
@@ -868,6 +934,16 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
 }
 
 
+//
+// 書き込み欄のテキストが更新された
+//
+void MessageViewBase::slot_text_changed()
+{
+    m_text_changed = true;
+    show_status();
+    m_text_changed = false;
+}
+
 
 //
 // ステータス表示
@@ -876,10 +952,20 @@ void MessageViewBase::show_status()
 {
     if( ! m_text_message ) return;
 
+    const bool broken = is_broken();
+
     std::stringstream ss;
 
-    if( m_text_message ) ss << " [ 行数 " << m_text_message->get_buffer()->get_line_count();
-    if( m_max_line ) ss << "/ " << m_max_line;
+    int line_count = 0;
+    if( m_text_message ){
+        line_count = m_text_message->get_buffer()->get_line_count();
+        ss << " [ 行数 " << line_count;
+    }
+    if( m_max_line ){
+        ss << "/ " << m_max_line;
+        if( m_max_line < line_count ) m_over_lines = true;
+        else m_over_lines = false;
+    }
 
     const std::string message = m_text_message->get_text();
 
@@ -889,23 +975,31 @@ void MessageViewBase::show_status()
     {
         ss << "過多";
     }
-    else
+    else if( m_text_changed )
     {
         int byte_out;
         const char* msgc = message.c_str();
         std::string str_enc = m_iconv->convert( (char*)msgc, strlen( msgc ), byte_out );
-         m_lng_str_enc = str_enc.length();
+        m_lng_str_enc = str_enc.length();
 
-         // 特殊文字の文字数を計算
-         m_lng_str_enc += MISC::count_chr( str_enc, '\n' ) * 5; // " <br> " = 6バイト
-         m_lng_str_enc += MISC::count_chr( str_enc, '"' ) * 5; // &quot; = 6バイト
-         m_lng_str_enc += MISC::count_chr( str_enc, '<' ) * 3; // &lt; = 4バイト
-         m_lng_str_enc += MISC::count_chr( str_enc, '>' ) * 3; // &gt; = 4バイト
+        // 特殊文字の文字数を計算
+        m_lng_str_enc += MISC::count_chr( str_enc, '\n' ) * 5; // " <br> " = 6バイト
+        m_lng_str_enc += MISC::count_chr( str_enc, '"' ) * 5; // &quot; = 6バイト
+        m_lng_str_enc += MISC::count_chr( str_enc, '<' ) * 3; // &lt; = 4バイト
+        m_lng_str_enc += MISC::count_chr( str_enc, '>' ) * 3; // &gt; = 4バイト
 
         ss << m_lng_str_enc;
     }
+    else ss << m_lng_str_enc;
 
-    if( m_max_str ) ss << "/ " << m_max_str;
+    if( m_max_str ){
+        ss << "/ " << m_max_str;
+        if( m_max_str < m_lng_str_enc ) m_over_lng = true;
+        else m_over_lng = false;
+    }
+
+    if( DBTREE::get_unicode( get_url() ) == "pass" ) ss << " / unicode ○";
+    else if( DBTREE::get_unicode( get_url() ) == "change" ) ss << " / unicode ×";
 
     const time_t wtime = DBTREE::article_write_time( get_url() );
     if( wtime ) ss << "  /  最終書込 "
@@ -914,14 +1008,19 @@ void MessageViewBase::show_status()
     ss << " ]";
 
     set_status( ss.str() );
-    MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() + m_str_pass );
+    MESSAGE::get_admin()->set_command( "set_status", get_url(), m_str_pass + get_status() );
+
+    if( broken != is_broken() ){
+        MESSAGE::get_admin()->set_command( "redraw_toolbar" );
+        MESSAGE::get_admin()->set_command( "set_status_color", get_url(), get_color() );
+    }
 }
 
 
 //
 // 自分の書き込みの判定用データの保存
 //
-// 実況中など post_fin() がコールされる前に自分のスレが表示されてしまう時があるので
+// 実況中など post_fin() がコールされる前に自分のレスが表示されてしまう時があるので
 //  m_post->post_msg() する前に情報を保存しておく
 //
 void MessageViewBase::push_logitem()
