@@ -81,9 +81,13 @@ namespace SKELETON
         // ポップアップ時に全ての領域を表示できないならカーソルの上に表示
         bool m_popup_upside;
 
+        // ロード時にキャッシュを削除してからviewを再読み込みする
+        bool m_reget;
+
       protected:
 
-        void set_url( const std::string& url_new, const bool update_history );
+        // url_new に URL を変更
+        void set_url( const std::string& url_new );
 
         // Viewが所属するAdminクラス
         virtual Admin* get_admin() = 0;
@@ -162,6 +166,8 @@ namespace SKELETON
         View( const std::string& url, const std::string& arg1 = std::string(), const std::string& arg2 = std::string() );
         virtual ~View(){}
 
+        virtual void save_session() = 0;
+
         virtual const std::string& get_url(){ return m_url; }
 
         virtual void set_parent_win( Gtk::Window* parent_win ){ m_parent_win = parent_win; }
@@ -230,6 +236,10 @@ namespace SKELETON
         // 現在のオートリロードのモード取得
         const int get_autoreload_mode() const { return m_autoreload_mode; }
 
+        // ロード時にキャッシュを削除してからviewを再読み込みする
+        const bool get_reget() const{ return m_reget; }
+        void set_reget( const bool reget ){ m_reget = reget; }
+
         // アイコンのID取得
         virtual const int get_icon( const std::string& iconname ){ return -1; }
 
@@ -248,8 +258,8 @@ namespace SKELETON
         // 壊れているか
         virtual const bool is_broken(){ return false; }
 
-        // shutdown( SIGHUP )用
-        virtual void shutdown(){}
+        // ラベルやステータスバーの色
+        const std::string get_color();
 
         // キーを押した
         virtual const bool slot_key_press( GdkEventKey* event ){ return false; }
