@@ -25,10 +25,12 @@ namespace CORE
         VIEW_HISTTHREAD,
         VIEW_HISTCLOSE,
         VIEW_HISTBOARD,
+        VIEW_HISTCLOSEIMG,
 
         VIEW_BOARDVIEW,
         VIEW_BOARDNEXT,
         VIEW_BOARDLOG,
+        VIEW_BOARDSIDEBAR,
 
         VIEW_ARTICLEVIEW,
         VIEW_ARTICLERES,
@@ -52,6 +54,7 @@ namespace CORE
         VIEW_ARTICLEPOPUPID,
         VIEW_ARTICLEPOPUPREFER,
         VIEW_ARTICLEPOPUPDRAWOUT,
+        VIEW_ARTICLEPOPUPBM,
 
         VIEW_IMAGEVIEW,
         VIEW_IMAGEICON,
